@@ -22,8 +22,6 @@ Philippe "BooK" Bruhat.
 
 Introduced in version 0.29, published on July 4, 2005.
 
-Updated by Abigail in version 0.91, publish on September 11, 2006.
-
 =head1 SEE ALSO
 
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
@@ -32,22 +30,22 @@ L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
 
 __DATA__
 # names
-apostrophe prime
+apostrophe
 brackets
 parentheses round_brackets parens fingernails
 square_brackets
 curly_brackets braces
-angle_brackets chevrons fishhooks
+angle_brackets chevrons
 corner_brackets
 comma
 dash emdash endash
 ellipsis suspension_points
-exclamation_mark inverted_exclamation_mark
+exclamation mark
 full_stop period
 hyphen
 interrobang
-question_mark inverted_question_mark
-quotation_marks single_quotes double_quotes backquotes
+question_mark
+quotation_marks single_quotes double_quotes backquote
 angle_quotes single_angle_quotes double_angle_quotes
 quotation_dash
 guillemets
@@ -55,22 +53,4 @@ semicolon
 slash solidus
 space
 interpunct
-colon
-ampersand
-asteriks
-asterism
-at
-backslash
-bullet
-caret
-currency
-dagger
-degree
-number_sign octothorpe
-percent_sign permille_sign
-pilcrow paragraph_mark
-section_mark
-tilde
-underscore
-umlaut deaeresis
-pipe vertical_bar broken_bar
+
